@@ -51,20 +51,21 @@ def read_tabular(
     if headers is None:
         headers = 1
         datasetinfo["headers"] = 1
+    kwargs["headers"] = headers
     if isinstance(headers, list):
         kwargs["fill_merged_cells"] = True
     format = datasetinfo["format"]
+    kwargs["format"] = format
     if not sheet and format in ("xls", "xlsx"):
         sheet = 1
+    if sheet:
+        kwargs["sheet"] = sheet
     compression = datasetinfo.get("compression")
     if compression:
         kwargs["compression"] = compression
     return downloader.get_tabular_rows(
         url,
-        sheet=sheet,
-        headers=headers,
         dict_form=True,
-        format=format,
         **kwargs,
     )
 
